#[non_exhaustive]pub struct Example {
pub summary: String,
pub description: String,
pub value: Option<Value>,
pub data_value: Option<Value>,
pub serialized_value: Option<String>,
pub external_value: String,
}Expand description
Implements OpenAPI Example Object.
Example is used on path operations to describe possible response bodies.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.summary: StringShort description for the Example.
description: StringLong description for the Example. Value supports markdown syntax for rich text
representation.
value: Option<Value>Embedded literal example value. Example::value and Example::external_value are
mutually exclusive.
data_value: Option<Value>Embedded example value in the same form as data validated by a schema.
serialized_value: Option<String>String representation of the example value after serialization.
external_value: StringAn URI that points to a literal example value. Example::external_value provides the
capability to references an example that cannot be easily included in JSON or YAML.
Example::value and Example::external_value are mutually exclusive.
Implementations
Sourceimpl Example
impl Example
Sourcepub fn builder() -> ExampleBuilder
pub fn builder() -> ExampleBuilder
Construct a new ExampleBuilder.
This is effectively same as calling ExampleBuilder::new