HeaderBuilder

Struct HeaderBuilder 

pub struct HeaderBuilder { /* private fields */ }
Builder for Header with chainable configuration methods to create a new Header.

Implementations

Source

impl HeaderBuilder

pub fn new() -> HeaderBuilder

Constructs a new HeaderBuilder.

pub fn build(self) -> Header

Constructs a new Header taking all fields values from this object.

Source

impl HeaderBuilder

pub fn schema<I: Into<RefOr<Schema>>>(self, component: I) -> Self

Add schema of header.

pub fn description<S: Into<String>>(self, description: Option<S>) -> Self

Add additional description for header.

pub fn deprecated(self, deprecated: Option<Deprecated>) -> Self

Add or change Header deprecated status.

pub fn style(self, style: Option<ParameterStyle>) -> Self

Add or change serialization style of Header.

pub fn explode(self, explode: Option<bool>) -> Self

Define whether Headers are exploded or not.

pub fn example(self, example: Option<Value>) -> Self

Add or change example of Header’s potential value.

pub fn examples_from_iter<E: IntoIterator<Item = (N, V)>, N: Into<String>, V: Into<RefOr<Example>>>( self, examples: E, ) -> Self

Add examples from iterator.

pub fn content_from_iter<E: IntoIterator<Item = (N, V)>, N: Into<String>, V: Into<Content>>( self, content: E, ) -> Self

Add media type content representation to Header.

pub fn extensions(self, extensions: Option<Extensions>) -> Self

Add openapi extensions (x-something) to the Header.