pub struct PathItemBuilder { /* private fields */ }Expand description
Implementations
Sourceimpl PathItemBuilder
impl PathItemBuilder
Sourcepub fn new() -> PathItemBuilder
pub fn new() -> PathItemBuilder
Constructs a new PathItemBuilder.
Sourceimpl PathItemBuilder
impl PathItemBuilder
Sourcepub fn ref_path<S: Into<String>>(self, ref_path: Option<S>) -> Self
pub fn ref_path<S: Into<String>>(self, ref_path: Option<S>) -> Self
Add or change reference to another Path Item Object.
Sourcepub fn operation<O: Into<Operation>>(
self,
http_method: HttpMethod,
operation: O,
) -> Self
pub fn operation<O: Into<Operation>>( self, http_method: HttpMethod, operation: O, ) -> Self
Append a new Operation by HttpMethod to this PathItem. Operations can
hold only one operation per HttpMethod.
Sourcepub fn additional_operations<I: IntoIterator<Item = (S, O)>, S: Into<String>, O: Into<Operation>>(
self,
additional_operations: I,
) -> Self
pub fn additional_operations<I: IntoIterator<Item = (S, O)>, S: Into<String>, O: Into<Operation>>( self, additional_operations: I, ) -> Self
Add or change operation used for HTTP methods or other operations not explicitly listed on this path.
Sourcepub fn additional_operation<S: Into<String>, O: Into<Operation>>(
self,
method: S,
operation: O,
) -> Self
pub fn additional_operation<S: Into<String>, O: Into<Operation>>( self, method: S, operation: O, ) -> Self
Add operation used for an HTTP method not explicitly listed on this path.
Sourcepub fn summary<S: Into<String>>(self, summary: Option<S>) -> Self
pub fn summary<S: Into<String>>(self, summary: Option<S>) -> Self
Add or change summary intended to apply all operations in this PathItem.
Sourcepub fn description<S: Into<String>>(self, description: Option<S>) -> Self
pub fn description<S: Into<String>>(self, description: Option<S>) -> Self
Add or change optional description intended to apply all operations in this PathItem.
Description supports markdown syntax.
Sourcepub fn servers<I: IntoIterator<Item = Server>>(self, servers: Option<I>) -> Self
pub fn servers<I: IntoIterator<Item = Server>>(self, servers: Option<I>) -> Self
Sourcepub fn parameters<I: IntoIterator<Item = Parameter>>(
self,
parameters: Option<I>,
) -> Self
pub fn parameters<I: IntoIterator<Item = Parameter>>( self, parameters: Option<I>, ) -> Self
Sourcepub fn parameter_refs<I: IntoIterator<Item = Ref>>(
self,
refs: Option<I>,
) -> Self
pub fn parameter_refs<I: IntoIterator<Item = Ref>>( self, refs: Option<I>, ) -> Self
Sourcepub fn extensions(self, extensions: Option<Extensions>) -> Self
pub fn extensions(self, extensions: Option<Extensions>) -> Self
Add openapi extensions (x-something) to this PathItem.